NigeriaData class

Constructors

NigeriaData()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getLgas(String stateIsoCode) List<City>
Returns all LGAs for a given State ISO Code as csc.City objects.
getStates() List<State>

Constants

countryCode → const String