AppBarSecurityConfig class

Constructors

AppBarSecurityConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

enableSecurityLogging ↔ bool
getter/setter pair
enforceValidation ↔ bool
getter/setter pair
maxActionsCount ↔ int
getter/setter pair
maxAppBarHeight ↔ double
getter/setter pair
maxElevation ↔ double
getter/setter pair
maxHintLength ↔ int
getter/setter pair
maxIconSize ↔ double
getter/setter pair
maxTabCount ↔ int
getter/setter pair
maxTitleFontSize ↔ double
getter/setter pair
maxTitleLength ↔ int
getter/setter pair
minAppBarHeight ↔ double
getter/setter pair
minIconSize ↔ double
getter/setter pair
minTitleFontSize ↔ double
getter/setter pair

Static Methods

disableSecurity() → void
enableSecurity() → void
resetToDefaults() → void
Reset all settings to defaults.