ButtonSecurityConfig class

Constructors

ButtonSecurityConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultCooldownDuration ↔ Duration
getter/setter pair
defaultDebounceDuration ↔ Duration
getter/setter pair
enableSecurityLogging ↔ bool
getter/setter pair
enforceValidation ↔ bool
getter/setter pair
maxBorderRadius ↔ double
getter/setter pair
maxButtonSize ↔ double
getter/setter pair
maxElevation ↔ double
getter/setter pair
maxFontSize ↔ double
getter/setter pair
minButtonSize ↔ double
getter/setter pair
minFontSize ↔ double
getter/setter pair

Static Methods

disableSecurity() → void
enableSecurity() → void
resetToDefaults() → void
setDefaultCooldownDuration(Duration duration) → void
setDefaultDebounceDuration(Duration duration) → void