SearchRateLimiter class

Rate limiter for search queries to prevent abuse.

Constructors

SearchRateLimiter({int maxQueriesPerMinute = 60})

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxQueriesPerMinute → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isQueryAllowed() → bool
Check if a new query is allowed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Reset the rate limiter.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited