TextSecurityConfig class

Security configuration for Text widgets.

Security is OFF by default. Enable it globally or per-widget.

Example:

// Enable security globally
TextSecurityConfig.enableSecurity();

// Or per-widget
AppText(
  'Hello',
  enableSecurity: true,
)

Constructors

TextSecurityConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

enableSecurityLogging ↔ bool
Enable debug logging for security events.
getter/setter pair
enforceValidation ↔ bool
Whether to enforce validation. Defaults to false (security OFF).
getter/setter pair
maxDecorationThickness ↔ double
Maximum decoration thickness
getter/setter pair
maxFontSize ↔ double
Maximum font size
getter/setter pair
maxLetterSpacing ↔ double
Maximum letter spacing
getter/setter pair
maxLineHeight ↔ double
Maximum line height multiplier
getter/setter pair
maxMaxLines ↔ int
Maximum max lines
getter/setter pair
maxShadowBlurRadius ↔ double
Maximum shadow blur radius
getter/setter pair
maxShadowCount ↔ int
Maximum number of shadows
getter/setter pair
maxTextLength ↔ int
Maximum allowed text length (to prevent memory issues)
getter/setter pair
maxTextScaleFactor ↔ double
Maximum text scale factor
getter/setter pair
maxWordSpacing ↔ double
Maximum word spacing
getter/setter pair
minFontSize ↔ double
Minimum font size
getter/setter pair
minLetterSpacing ↔ double
Minimum letter spacing
getter/setter pair
minLineHeight ↔ double
Minimum line height multiplier
getter/setter pair
minTextScaleFactor ↔ double
Minimum text scale factor
getter/setter pair
minWordSpacing ↔ double
Minimum word spacing
getter/setter pair

Static Methods

disableSecurity() → void
Disable security validation globally.
enableSecurity() → void
Enable security validation globally.
resetToDefaults() → void
Reset all settings to defaults.