TextFieldSecurityConfig class

Security configuration for TextField widgets.

Security is OFF by default. Enable it globally or per-widget.

Example:

// Enable security globally
TextFieldSecurityConfig.enableSecurity();

// Or per-widget
AppTextField(
  enableSecurity: true,
)

Constructors

TextFieldSecurityConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

enableSecurityLogging ↔ bool
Enable debug logging for security events.
getter/setter pair
enforceValidation ↔ bool
Whether to enforce validation. Defaults to false (security OFF).
getter/setter pair
maxBorderRadius ↔ double
Maximum border radius
getter/setter pair
maxBorderWidth ↔ double
Maximum border width
getter/setter pair
maxContentPadding ↔ double
Maximum content padding
getter/setter pair
maxFontSize ↔ double
Maximum font size
getter/setter pair
maxHeight ↔ double
Maximum height
getter/setter pair
maxIconSize ↔ double
Maximum icon size
getter/setter pair
maxInputLength ↔ int
Maximum allowed input length
getter/setter pair
maxLabelSpacing ↔ double
Maximum label spacing
getter/setter pair
maxMaxLines ↔ int
Maximum max lines
getter/setter pair
maxMinLines ↔ int
Maximum min lines
getter/setter pair
minFontSize ↔ double
Minimum font size
getter/setter pair
minHeight ↔ double
Minimum height
getter/setter pair
minIconSize ↔ double
Minimum icon size
getter/setter pair

Static Methods

disableSecurity() → void
Disable security validation globally.
enableSecurity() → void
Enable security validation globally.
resetToDefaults() → void
Reset all settings to defaults.