SACThemeBase class abstract

Base class to create your own themed variants while reusing SACTheme builders.

Constructors

SACThemeBase()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

config() → SACThemeConfig?
Provide your custom config. Return null to use defaults.
dark() → ThemeData
light() → ThemeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited