CustomSliverAppBar class

A secure sliver version of CustomAppBar for use in CustomScrollView.

Inheritance

Constructors

CustomSliverAppBar({Key? key, String? title, Widget? titleWidget, double expandedHeight = 200.0, double collapsedHeight = 60.0, bool pinned = true, bool floating = false, bool snap = false, bool stretch = false, double stretchTriggerOffset = 100.0, VoidCallback? onStretchTrigger, Widget? leading, bool showBackButton = true, IconData backIcon = Icons.arrow_back_ios, Color? backIconColor, VoidCallback? onBack, List<Widget>? actions, List<Color>? gradientColors, AlignmentGeometry gradientBegin = Alignment.topLeft, AlignmentGeometry gradientEnd = Alignment.bottomRight, Color? backgroundColor, Color? foregroundColor, double elevation = 0, bool centerTitle = true, Widget? flexibleSpace, PreferredSizeWidget? bottom, ShapeBorder? shape, Color? titleColor, double titleFontSize = 20.0, FontWeight titleFontWeight = FontWeight.bold, String? semanticLabel, bool? enableSecurity})
const

Properties

actions → List<Widget>?
final
backgroundColor → Color?
final
backIcon → IconData
final
backIconColor → Color?
final
bottom → PreferredSizeWidget?
final
centerTitle → bool
final
collapsedHeight → double
final
elevation → double
final
enableSecurity → bool?
final
expandedHeight → double
final
flexibleSpace → Widget?
final
floating → bool
final
foregroundColor → Color?
final
gradientBegin → AlignmentGeometry
final
gradientColors → List<Color>?
final
gradientEnd → AlignmentGeometry
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
final
onBack → VoidCallback?
final
onStretchTrigger → VoidCallback?
final
pinned → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
final
shape → ShapeBorder?
final
showBackButton → bool
final
snap → bool
final
stretch → bool
final
stretchTriggerOffset → double
final
title → String?
final
titleColor → Color?
final
titleFontSize → double
final
titleFontWeight → FontWeight
final
titleWidget → Widget?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited