SearchAppBar class

Secure SearchAppBar with input validation and safe callbacks.

Inheritance
Implemented types

Constructors

SearchAppBar({Key? key, String? hintText = 'Search...', TextEditingController? controller, ValueChanged<String>? onChanged, ValueChanged<String>? onSubmitted, VoidCallback? onBack, VoidCallback? onClear, bool autofocus = true, Color? backgroundColor, List<Color>? gradientColors, Color? iconColor, Color? textColor, Color? hintColor, double height = 60.0, List<Widget>? actions, InputDecoration? inputDecoration, TextStyle? textStyle, bool showBackButton = true, IconData backIcon = Icons.arrow_back_ios, bool showClearButton = true, int maxSearchLength = 200, String? semanticLabel, bool? enableSecurity})
const

Properties

actions → List<Widget>?
final
autofocus → bool
final
backgroundColor → Color?
final
backIcon → IconData
final
controller → TextEditingController?
final
enableSecurity → bool?
final
gradientColors → List<Color>?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
hintColor → Color?
final
hintText → String?
final
iconColor → Color?
final
inputDecoration → InputDecoration?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxSearchLength → int
final
onBack → VoidCallback?
final
onChanged → ValueChanged<String>?
final
onClear → VoidCallback?
final
onSubmitted → ValueChanged<String>?
final
preferredSize → Size
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
final
showBackButton → bool
final
showClearButton → bool
final
textColor → Color?
final
textStyle → TextStyle?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited