TabbedAppBar class

Secure TabbedAppBar with input validation and safe callbacks.

Inheritance
Implemented types

Constructors

TabbedAppBar({Key? key, String? title, Widget? titleWidget, required List<Widget> tabs, TabController? controller, bool isScrollable = false, Color? backgroundColor, List<Color>? gradientColors, Color? indicatorColor, Color? labelColor, Color? unselectedLabelColor, double height = 60.0, double tabBarHeight = 48.0, Widget? leading, bool showBackButton = true, VoidCallback? onBack, List<Widget>? actions, TabBarIndicatorSize indicatorSize = TabBarIndicatorSize.label, EdgeInsetsGeometry? indicatorPadding, Decoration? indicator, String? semanticLabel, bool? enableSecurity})
const

Properties

actions → List<Widget>?
final
backgroundColor → Color?
final
controller → TabController?
final
enableSecurity → bool?
final
gradientColors → List<Color>?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
indicator → Decoration?
final
indicatorColor → Color?
final
indicatorPadding → EdgeInsetsGeometry?
final
indicatorSize → TabBarIndicatorSize
final
isScrollable → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelColor → Color?
final
leading → Widget?
final
onBack → VoidCallback?
final
preferredSize → Size
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
final
showBackButton → bool
final
tabBarHeight → double
final
tabs → List<Widget>
final
title → String?
final
titleWidget → Widget?
final
unselectedLabelColor → Color?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited