TransparentAppBar class

A simple transparent AppBar for overlaying content.

Inheritance

Constructors

TransparentAppBar({Key? key, String? title, Widget? titleWidget, List<Widget>? actions, Widget? leading, bool showBackButton = true, IconData backIcon = Icons.arrow_back_ios, Color? backIconColor, VoidCallback? onBack, double elevation = 0, SystemUiOverlayStyle? systemOverlayStyle = SystemUiOverlayStyle.light, String? semanticLabel, bool? enableSecurity, Color? foregroundColor})
const

Properties

actions → List<Widget>?
finalinherited
actionsIconTheme → IconThemeData?
finalinherited
actionsIconThemePadding → double
finalinherited
automaticallyImplyLeading → bool?
finalinherited
backgroundColor → Color?
finalinherited
backIcon → IconData
finalinherited
backIconColor → Color?
finalinherited
backIconSize → double
finalinherited
bottom → PreferredSizeWidget?
finalinherited
bottomOpacity → double
finalinherited
centerTitle → bool
finalinherited
clipBehavior → Clip
finalinherited
elevation → double
finalinherited
enableSecurity → bool?
finalinherited
excludeHeaderSemantics → bool
finalinherited
flexibleSpace → Widget?
finalinherited
flexibleSpaceDecoration → BoxDecoration?
finalinherited
forceMaterialTransparency → bool
finalinherited
foregroundColor → Color?
finalinherited
gradientBegin → AlignmentGeometry
finalinherited
gradientColors → List<Color>?
finalinherited
gradientEnd → AlignmentGeometry
finalinherited
gradientStops → List<double>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double
finalinherited
iconTheme → IconThemeData?
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
finalinherited
leadingWidth → double?
finalinherited
notificationPredicate → ScrollNotificationPredicate?
finalinherited
onBack → VoidCallback?
finalinherited
preferredSize → Size
The size this widget would prefer if it were otherwise unconstrained.
no setterinherited
primary → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
finalinherited
shadowColor → Color?
finalinherited
shape → ShapeBorder?
finalinherited
showBackButton → bool
finalinherited
surfaceTintColor → Color?
finalinherited
systemOverlayStyle → SystemUiOverlayStyle?
finalinherited
title → String?
finalinherited
titleColor → Color?
finalinherited
titleFontSize → double
finalinherited
titleFontWeight → FontWeight
finalinherited
titleTextStyle → TextStyle?
finalinherited
titleWidget → Widget?
finalinherited
toolbarHeight → double?
finalinherited
toolbarOpacity → double
finalinherited
toolbarTextStyle → TextStyle?
finalinherited
transparent → bool
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited