AppSecondaryElevatedButton class

Secondary elevated button with debouncing and security features.

Inheritance

Constructors

AppSecondaryElevatedButton({Key? key, required String label, void onPressed()?, Color? bgColor, Color? textColor, double? width, double? height, double? radius, EdgeInsetsGeometry? padding, double? elevation, bool isLoading = false, bool enabled = true, IconData? prefixIcon, IconData? suffixIcon, bool enableDebounce = true, Duration debounceDuration = const Duration(milliseconds: 300), String? semanticLabel, bool? enableSecurity})
const

Properties

bgColor → Color?
final
debounceDuration → Duration
final
elevation → double?
final
enabled → bool
final
enableDebounce → bool
final
enableSecurity → bool?
Enable security validation (size limits, text sanitization). Defaults to null (uses global ButtonSecurityConfig.enforceValidation). Set to true to force enable, false to force disable.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
isLoading → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String
final
onPressed → void Function()?
final
padding → EdgeInsetsGeometry?
final
prefixIcon → IconData?
final
radius → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
final
suffixIcon → IconData?
final
textColor → Color?
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AppSecondaryElevatedButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited