AppText class

A highly customizable text widget with extensive configuration options.

Features:

  • Multiple style presets (small, medium, large, heading, display, caption, label)
  • Full typography customization
  • Text decorations (underline, strikethrough, etc.)
  • Gradient text support
  • Selectable text option
  • Tap gestures with callbacks
  • Rich text with highlighted portions
  • Security validation

Example usage:

AppText(
  'Hello World',
  style: AppTextStyle.heading,
  color: AppColors.primary,
  fontWeight: FontWeight.bold,
  gradient: LinearGradient(colors: [Colors.blue, Colors.purple]),
)
Inheritance

Constructors

AppText(String data, {Key? key, AppTextStyle style = AppTextStyle.medium, TextStyle? textStyle, Color? color, Color? backgroundColor, Color? decorationColor, Gradient? gradient, double? fontSize, FontWeight? fontWeight, String? fontFamily, FontStyle? fontStyle, double? letterSpacing, double? wordSpacing, double? height, AppTextDecoration? decoration, TextDecorationStyle? decorationStyle, double? decorationThickness, TextAlign? textAlign, TextDirection? textDirection, int? maxLines, TextOverflow? overflow, bool? softWrap, List<Shadow>? shadows, VoidCallback? onTap, VoidCallback? onLongPress, VoidCallback? onDoubleTap, bool selectable = false, String? semanticsLabel, bool? enableSecurity})
const

Properties

backgroundColor → Color?
final
color → Color?
final
data → String
final
decoration → AppTextDecoration?
final
decorationColor → Color?
final
decorationStyle → TextDecorationStyle?
final
decorationThickness → double?
final
enableSecurity → bool?
final
fontFamily → String?
final
fontSize → double?
final
fontStyle → FontStyle?
final
fontWeight → FontWeight?
final
gradient → Gradient?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
letterSpacing → double?
final
maxLines → int?
final
onDoubleTap → VoidCallback?
final
onLongPress → VoidCallback?
final
onTap → VoidCallback?
final
overflow → TextOverflow?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectable → bool
final
semanticsLabel → String?
final
shadows → List<Shadow>?
final
softWrap → bool?
final
style → AppTextStyle
final
textAlign → TextAlign?
final
textDirection → TextDirection?
final
textStyle → TextStyle?
final
wordSpacing → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited