HighlightedText class

A rich text widget with highlighted portions.

Example:

HighlightedText(
  text: 'Hello World, this is a test',
  highlights: ['World', 'test'],
  highlightColor: Colors.yellow,
)
Inheritance

Constructors

HighlightedText({Key? key, required String text, required List<String> highlights, Color? highlightColor, Color? highlightTextColor, FontWeight? highlightFontWeight, Color? highlightBackgroundColor, bool caseSensitive = false, Color? color, double? fontSize, FontWeight? fontWeight, String? fontFamily, TextStyle? textStyle, int? maxLines, TextAlign? textAlign, TextOverflow? overflow, void onHighlightTap(String)?, bool? enableSecurity})
const

Properties

caseSensitive → bool
final
color → Color?
final
enableSecurity → bool?
final
fontFamily → String?
final
fontSize → double?
final
fontWeight → FontWeight?
final
hashCode → int
The hash code for this object.
no setterinherited
highlightBackgroundColor → Color?
final
highlightColor → Color?
final
highlightFontWeight → FontWeight?
final
highlights → List<String>
final
highlightTextColor → Color?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLines → int?
final
onHighlightTap → void Function(String)?
final
overflow → TextOverflow?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final
textAlign → TextAlign?
final
textStyle → TextStyle?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited