MedAppText class

Convenience widget for medium text

Inheritance

Constructors

MedAppText(String data, {Key? key, Color? color, double? fontSize, FontWeight? fontWeight, TextAlign? alignment, int? maxLines, FontStyle? fontStyle, double? letterSpacing, double? wordSpacing, double? height, AppTextDecoration? decoration, Color? decorationColor, TextDecorationStyle? decorationStyle, double? decorationThickness, TextOverflow? overflow, bool? softWrap, List<Shadow>? shadows, VoidCallback? onTap, bool selectable = false, TextStyle? textStyle, Color? backgroundColor, Gradient? gradient, String? semanticsLabel, bool? enableSecurity})
const

Properties

alignment → TextAlign?
final
backgroundColor → Color?
final
color → Color?
final
data → String
final
decoration → AppTextDecoration?
final
decorationColor → Color?
final
decorationStyle → TextDecorationStyle?
final
decorationThickness → double?
final
enableSecurity → bool?
final
fontSize → double?
final
fontStyle → FontStyle?
final
fontWeight → FontWeight?
final
gradient → Gradient?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
letterSpacing → double?
final
maxLines → int?
final
onTap → VoidCallback?
final
overflow → TextOverflow?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectable → bool
final
semanticsLabel → String?
final
shadows → List<Shadow>?
final
softWrap → bool?
final
textStyle → TextStyle?
final
wordSpacing → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited