PriceText class

A customizable price/currency text widget with formatting.

Features:

  • Multiple currency support
  • Automatic number formatting with commas
  • Profit/loss indicators
  • Decimal control
  • Full typography customization

Example:

PriceText(
  price: '1234567.89',
  currency: Currency.usd,
  isProfit: true,
  showDecimals: true,
)
Inheritance

Constructors

PriceText({Key? key, required String price, Currency currency = Currency.tl, String? customCurrencySymbol, CurrencyPosition currencyPosition = CurrencyPosition.before, double? currencySpacing, bool showDecimals = true, int decimalPlaces = 2, String thousandsSeparator = ',', String decimalSeparator = '.', bool? isProfit, bool compactFormat = false, int? maxLength, Color? color, double? fontSize, FontWeight? fontWeight, String? fontFamily, TextStyle? textStyle, int? maxLines = 1, TextAlign? textAlign = TextAlign.left, TextOverflow? overflow, Color? profitColor, Color? lossColor, String profitPrefix = '+ ', String lossPrefix = '- ', bool showProfitLossColors = true, bool? enableSecurity})
const

Properties

color → Color?
final
compactFormat → bool
final
currency → Currency
final
currencyPosition → CurrencyPosition
final
currencySpacing → double?
final
customCurrencySymbol → String?
final
decimalPlaces → int
final
decimalSeparator → String
final
enableSecurity → bool?
final
fontFamily → String?
final
fontSize → double?
final
fontWeight → FontWeight?
final
hashCode → int
The hash code for this object.
no setterinherited
isProfit → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lossColor → Color?
final
lossPrefix → String
final
maxLength → int?
final
maxLines → int?
final
overflow → TextOverflow?
final
price → String
final
profitColor → Color?
final
profitPrefix → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDecimals → bool
final
showProfitLossColors → bool
final
textAlign → TextAlign?
final
textStyle → TextStyle?
final
thousandsSeparator → String
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited