AppPhoneTextField class

A robust, beautiful phone text field with pixel-perfect country flags. Flags are rendered using high-fidelity asset images bundled in intl_phone_field.

Inheritance

Constructors

AppPhoneTextField({Key? key, TextEditingController? controller, String? label, String? hint, void onChanged(PhoneNumber)?, void onCountryChanged(String)?, String? validator(PhoneNumber?)?, String initialCountryCode = 'NG', LabelPosition labelPosition = LabelPosition.above, TextStyle? labelStyle, double? labelFontSize, FontWeight? labelFontWeight, Color? labelColor, double? labelSpacing, double? borderRadius, double? borderWidth, Color? borderColor, Color? focusedBorderColor, Color? errorBorderColor, Color? backgroundColor, Color? cursorColor, Color? textColor, Color? hintColor, Color? dropdownIconColor, bool showDropdownIcon = true, bool showCountryFlag = true, bool enabled = true, bool readOnly = false, bool isRequired = false, Color? requiredIndicatorColor, String? invalidNumberMessage, bool? enableSecurity, double? height, EdgeInsetsGeometry? contentPadding, String? phoneValidator(String?)?, bool allowLeadingZero = false, AutovalidateMode? autovalidateMode})
const

Properties

allowLeadingZero → bool
final
autovalidateMode → AutovalidateMode?
final
backgroundColor → Color?
final
borderColor → Color?
final
borderRadius → double?
final
borderWidth → double?
final
contentPadding → EdgeInsetsGeometry?
final
controller → TextEditingController?
final
cursorColor → Color?
final
final
enabled → bool
final
enableSecurity → bool?
final
errorBorderColor → Color?
final
focusedBorderColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
hint → String?
final
hintColor → Color?
final
initialCountryCode → String
final
invalidNumberMessage → String?
final
isRequired → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String?
final
labelColor → Color?
final
labelFontSize → double?
final
labelFontWeight → FontWeight?
final
labelPosition → LabelPosition
final
labelSpacing → double?
final
labelStyle → TextStyle?
final
onChanged → void Function(PhoneNumber)?
final
onCountryChanged → void Function(String)?
final
phoneValidator → String? Function(String?)?
final
readOnly → bool
final
requiredIndicatorColor → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCountryFlag → bool
final
showDropdownIcon → bool
final
textColor → Color?
final
validator → String? Function(PhoneNumber?)?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AppPhoneTextField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited