FilterableSearchBar class

A search bar with filter chips for category/tag filtering.

Example:

FilterableSearchBar(
  filters: ['All', 'Products', 'Users', 'Orders'],
  selectedFilter: 'All',
  onFilterChanged: (filter) => setFilter(filter),
  onSearch: (query) => performSearch(query),
)
Inheritance

Constructors

FilterableSearchBar({Key? key, required List<String> filters, required String selectedFilter, required void onFilterChanged(String), void onSearch(String)?, void onChanged(String)?, TextEditingController? controller, String? hintText, SearchBarStyle style = SearchBarStyle.rounded, TextStyle? chipStyle, TextStyle? selectedChipStyle, double? spacing, bool filterScrollable = true, double? filterHeight, double? chipPaddingHorizontal, double? chipPaddingVertical, double? chipBorderRadius, Color? selectedChipColor, Color? unselectedChipColor, Color? selectedTextColor, Color? unselectedTextColor, double? chipFontSize, FontWeight? chipFontWeight, FontWeight? selectedChipFontWeight, Duration? animationDuration})
const

Properties

animationDuration → Duration?
final
chipBorderRadius → double?
final
chipFontSize → double?
final
chipFontWeight → FontWeight?
final
chipPaddingHorizontal → double?
final
chipPaddingVertical → double?
final
chipStyle → TextStyle?
final
controller → TextEditingController?
final
filterHeight → double?
final
filters → List<String>
final
filterScrollable → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged → void Function(String)?
final
onFilterChanged → void Function(String)
final
onSearch → void Function(String)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedChipColor → Color?
final
selectedChipFontWeight → FontWeight?
final
selectedChipStyle → TextStyle?
final
selectedFilter → String
final
selectedTextColor → Color?
final
spacing → double?
final
style → SearchBarStyle
final
unselectedChipColor → Color?
final
unselectedTextColor → Color?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited