AppMultiLineTextField class

Multiline text field for longer text input

Inheritance

Constructors

AppMultiLineTextField({Key? key, TextEditingController? controller, FocusNode? focusNode, String? label, String? hint, String? helperText, String? validator(String?)?, void onChanged(String)?, void onSubmitted(String)?, LabelPosition labelPosition = LabelPosition.above, TextFieldStyle fieldStyle = TextFieldStyle.outlined, int minLines = 3, int maxLines = 10, int? maxLength, bool showCounter = false, TextInputType keyboardType = TextInputType.multiline, TextInputAction textInputAction = TextInputAction.newline, bool enabled = true, bool readOnly = false, bool isRequired = false, double? borderRadius, Color? borderColor, Color? focusedBorderColor, Color? backgroundColor, EdgeInsetsGeometry? contentPadding, double? labelFontSize, double? fontSize, double? hintFontSize, bool? enableSecurity})
const

Properties

backgroundColor → Color?
final
borderColor → Color?
final
borderRadius → double?
final
contentPadding → EdgeInsetsGeometry?
final
controller → TextEditingController?
final
enabled → bool
final
enableSecurity → bool?
final
fieldStyle → TextFieldStyle
final
focusedBorderColor → Color?
final
focusNode → FocusNode?
final
fontSize → double?
final
hashCode → int
The hash code for this object.
no setterinherited
helperText → String?
final
hint → String?
final
hintFontSize → double?
final
isRequired → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType
final
label → String?
final
labelFontSize → double?
final
labelPosition → LabelPosition
final
maxLength → int?
final
maxLines → int
final
minLines → int
final
onChanged → void Function(String)?
final
onSubmitted → void Function(String)?
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCounter → bool
final
textInputAction → TextInputAction
final
validator → String? Function(String?)?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited