AppPasswordField class

Inheritance

Constructors

AppPasswordField({Key? key, TextEditingController? controller, FocusNode? focusNode, String? label, String? hint, String? validator(String?)?, void onChanged(String)?, void onSubmitted(String)?, LabelPosition labelPosition = LabelPosition.above, TextFieldStyle fieldStyle = TextFieldStyle.outlined, TextInputAction? textInputAction, bool autofocus = false, bool enabled = true, bool isRequired = false, bool showPasswordToggle = true, double? borderRadius, Color? borderColor, Color? focusedBorderColor, IconData? prefixIconData, bool? enableSecurity, double? height})
const

Properties

autofocus → bool
final
borderColor → Color?
final
borderRadius → double?
final
controller → TextEditingController?
final
enabled → bool
final
enableSecurity → bool?
final
fieldStyle → TextFieldStyle
final
focusedBorderColor → Color?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
hint → String?
final
isRequired → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String?
final
labelPosition → LabelPosition
final
onChanged → void Function(String)?
final
onSubmitted → void Function(String)?
final
prefixIconData → IconData?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showPasswordToggle → bool
final
textInputAction → TextInputAction?
final
validator → String? Function(String?)?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited