AppRoundedTextField class

Rounded/pill shaped text field for search and modern UIs

Inheritance

Constructors

AppRoundedTextField({Key? key, TextEditingController? controller, FocusNode? focusNode, String? hint, void onChanged(String)?, void onSubmitted(String)?, VoidCallback? onTap, String? validator(String?)?, IconData? prefixIconData, IconData? suffixIconData, Widget? prefixIcon, Widget? suffixIcon, TextInputType? keyboardType, TextInputAction? textInputAction, bool enabled = true, bool readOnly = false, bool autofocus = false, bool obscureText = false, bool showPasswordToggle = false, Color? backgroundColor, Color? borderColor, Color? focusedBorderColor, Color? cursorColor, Color? textColor, Color? hintColor, Color? iconColor, double? fontSize, double? hintFontSize, double? iconSize, double? height, EdgeInsetsGeometry? contentPadding, bool isPill = true, bool showBorder = false, bool? enableSecurity})
const

Properties

autofocus → bool
final
backgroundColor → Color?
final
borderColor → Color?
final
contentPadding → EdgeInsetsGeometry?
final
controller → TextEditingController?
final
cursorColor → Color?
final
enabled → bool
final
enableSecurity → bool?
final
focusedBorderColor → Color?
final
focusNode → FocusNode?
final
fontSize → double?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
hint → String?
final
hintColor → Color?
final
hintFontSize → double?
final
iconColor → Color?
final
iconSize → double?
final
isPill → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
final
obscureText → bool
final
onChanged → void Function(String)?
final
onSubmitted → void Function(String)?
final
onTap → VoidCallback?
final
prefixIcon → Widget?
final
prefixIconData → IconData?
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBorder → bool
final
showPasswordToggle → bool
final
suffixIcon → Widget?
final
suffixIconData → IconData?
final
textColor → Color?
final
textInputAction → TextInputAction?
final
validator → String? Function(String?)?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited