SACThemeExtension class
Theme extension for Swiss Army Component specific properties
- Inheritance
-
- Object
- ThemeExtension<
SACThemeExtension> - SACThemeExtension
Constructors
- SACThemeExtension({double? inputHeight, double? phoneFieldHeight, double? dropdownHeight, double? buttonHeight})
Properties
-
final
- dropdownHeight → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputHeight → double?
-
final
- phoneFieldHeight → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{double? inputHeight, double? phoneFieldHeight, double? dropdownHeight, double? buttonHeight}) → SACThemeExtension -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< SACThemeExtension> ? other, double t) → SACThemeExtension -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerpDouble(
double? a, double? b, double t) → double?