AppDropdown<T> class

Inheritance

Constructors

AppDropdown({Key? key, required List<DropdownMenuItem<T>>? items, required ValueChanged<T?>? onChanged, T? value, String? label, String? hint, Widget? prefixIcon, bool isLoading = false, FormFieldValidator<T>? validator, FormFieldSetter<T>? onSaved, TextFieldStyle fieldStyle = TextFieldStyle.outlined, LabelPosition labelPosition = LabelPosition.above, Color? backgroundColor, Color? borderColor, double? borderRadius, EdgeInsetsGeometry? contentPadding, double? height, bool enabled = true, bool isRequired = false, Color? requiredIndicatorColor})
const

Properties

backgroundColor → Color?
final
borderColor → Color?
final
borderRadius → double?
final
contentPadding → EdgeInsetsGeometry?
final
enabled → bool
final
fieldStyle → TextFieldStyle
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
hint → String?
final
isLoading → bool
final
isRequired → bool
final
items → List<DropdownMenuItem<T>>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String?
final
labelPosition → LabelPosition
final
onChanged → ValueChanged<T?>?
final
onSaved → ValueChanged<T?>?
final
prefixIcon → Widget?
final
requiredIndicatorColor → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validator → FormFieldValidator<T>?
final
value → T?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AppDropdown<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited